package com.autonavi.amapauto.protocol.control;

import com.autonavi.amapauto.protocol.AutoProtocolManager;
import com.autonavi.amapauto.protocol.constant.ProtocolResultCode;
import com.autonavi.amapauto.protocol.interaction.IProtocolBaseInterface;
import com.autonavi.amapauto.protocol.listener.IProtocolCallback;
import com.autonavi.amapauto.protocol.model.base.ProtocolBaseModel;
import com.autonavi.amapauto.protocol.model.base.ProtocolModel;
import com.autonavi.amapauto.protocol.model.client.BackToMapModel;
import com.autonavi.amapauto.protocol.model.client.MapOperaModel;
import com.autonavi.amapauto.protocol.model.client.ModifyNaviViaModel;
import com.autonavi.amapauto.protocol.model.client.NaviOperaModel;
import com.autonavi.amapauto.protocol.model.client.NaviRoutePreferModel;
import com.autonavi.amapauto.protocol.model.client.RequestFrontTrafficRadioModel;
import com.autonavi.amapauto.protocol.model.client.RequestGuideInfoModel;
import com.autonavi.amapauto.protocol.model.client.RequestHighwayExitModel;
import com.autonavi.amapauto.protocol.model.client.RequestRouteExModel;
import com.autonavi.amapauto.protocol.model.client.SelectRouteModel;
import com.autonavi.amapauto.protocol.model.client.SetSpecialPoiModel;
import com.autonavi.amapauto.protocol.model.client.ShowMyLocationModel;
import com.autonavi.amapauto.protocol.model.client.ShowTrafficModel;
import com.autonavi.amapauto.protocol.model.client.SpecialPoiNaviModel;
import com.autonavi.amapauto.protocol.model.client.drive_module.ShareTripByTelNumModel;
import com.autonavi.amapauto.protocol.model.client.search.AlongTheWaySearchModel;
import com.autonavi.amapauto.protocol.model.client.search.AroundSearchModel;
import com.autonavi.amapauto.protocol.model.client.search.KeyWordSearchModel;
import com.autonavi.amapauto.protocol.model.client.user.AckRequestBindUserModel;
import com.autonavi.amapauto.protocol.model.client.user.FavoriteCurrentPoiModel;
import com.autonavi.amapauto.protocol.model.client.user.FavoriteTypeModel;
import com.autonavi.amapauto.protocol.model.client.user.LogoutUserModel;
import com.autonavi.amapauto.protocol.model.client.user.RequestBindUserModel;
import com.autonavi.amapauto.protocol.model.client.user.RequestFavoritePoiModel;
import com.autonavi.amapauto.protocol.model.client.user.SetNaviMuteModel;
import com.autonavi.amapauto.protocol.model.service.ResponseOilVolume;
import com.autonavi.amapauto.protocol.model.service.ResponsePowerStatus;
/* loaded from: classes.dex */
public class ProtocolAPIControl implements IProtocolBaseInterface {
    private AutoProtocolManager mProtocolManager;

    public ProtocolAPIControl(AutoProtocolManager autoProtocolManager) {
        this.mProtocolManager = null;
        this.mProtocolManager = autoProtocolManager;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolMapInterface
    public int mapOpera(int i, int i2, IProtocolCallback iProtocolCallback) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendProtocolModelData(new MapOperaModel(i, i2), iProtocolCallback);
        }
        return ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolSearchInterface
    public int keywordSearch(KeyWordSearchModel keyWordSearchModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(keyWordSearchModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolSearchInterface
    public int aroundSearch(AroundSearchModel aroundSearchModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(aroundSearchModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolSearchInterface
    public int alongTheWaySearch(AlongTheWaySearchModel alongTheWaySearchModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(alongTheWaySearchModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolSearchInterface
    public int districtSearch(KeyWordSearchModel keyWordSearchModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(keyWordSearchModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolMapInterface
    public int backToMap(int i, IProtocolCallback iProtocolCallback) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendProtocolModelData(new BackToMapModel(i), iProtocolCallback);
        }
        return ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolMapInterface
    public int showMyLocation(int i, IProtocolCallback iProtocolCallback) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendProtocolModelData(new ShowMyLocationModel(i), iProtocolCallback);
        }
        return ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolMapInterface
    public int showTraffic(ShowTrafficModel showTrafficModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(showTrafficModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int specialPoiNavi(int i, int i2, IProtocolCallback iProtocolCallback) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendProtocolModelData(new SpecialPoiNaviModel(i, i2), iProtocolCallback);
        }
        return ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int requestRouteEx(RequestRouteExModel requestRouteExModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(requestRouteExModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int selectRoute(int i, IProtocolCallback iProtocolCallback) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendProtocolModelData(new SelectRouteModel(i), iProtocolCallback);
        }
        return ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int naviOpera(int i, int i2, IProtocolCallback iProtocolCallback) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendProtocolModelData(new NaviOperaModel(i, i2), iProtocolCallback);
        }
        return ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int modifyNaviVia(ModifyNaviViaModel modifyNaviViaModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(modifyNaviViaModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int changeNaviRoutePrefer(int i, IProtocolCallback iProtocolCallback) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendProtocolModelData(new NaviRoutePreferModel(i), iProtocolCallback);
        }
        return ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int requestGuideInfo(RequestGuideInfoModel requestGuideInfoModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(requestGuideInfoModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int shareTripByTelNum(ShareTripByTelNumModel shareTripByTelNumModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(shareTripByTelNumModel, iProtocolCallback) : ProtocolResultCode.RESULT_LISTENER_NULL;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int requestRouteInfo(ProtocolBaseModel protocolBaseModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(protocolBaseModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int requestHighwayExit(RequestHighwayExitModel requestHighwayExitModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(requestHighwayExitModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolDriveInterface
    public int requestFrontTrafficRadio(RequestFrontTrafficRadioModel requestFrontTrafficRadioModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(requestFrontTrafficRadioModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolSettingInterface
    public int setSpecialPOI(SetSpecialPoiModel setSpecialPoiModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(setSpecialPoiModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    public ProtocolModel getAutoData(RequestHighwayExitModel requestHighwayExitModel) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendSyncGetAutoData(requestHighwayExitModel);
        }
        return null;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolAutoUserInterface
    public int requestBindAutoUser(RequestBindUserModel requestBindUserModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(requestBindUserModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolAutoUserInterface
    public int ackRequestBindAutoUser(AckRequestBindUserModel ackRequestBindUserModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(ackRequestBindUserModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolAutoUserInterface
    public int logoutAutoAccount(LogoutUserModel logoutUserModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(logoutUserModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolCommonInterface
    public ProtocolModel sendOilVolume(ResponseOilVolume responseOilVolume) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendSyncGetAutoData(responseOilVolume);
        }
        return null;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolCommonInterface
    public ProtocolModel sendPowerStatus(ResponsePowerStatus responsePowerStatus) {
        if (this.mProtocolManager != null) {
            return this.mProtocolManager.sendSyncGetAutoData(responsePowerStatus);
        }
        return null;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolAutoUserInterface
    public int requestFavoriteByType(FavoriteTypeModel favoriteTypeModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(favoriteTypeModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolAutoUserInterface
    public int setFavoritePoi(RequestFavoritePoiModel requestFavoritePoiModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(requestFavoritePoiModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolAutoUserInterface
    public int favoriteCurrentPoi(FavoriteCurrentPoiModel favoriteCurrentPoiModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(favoriteCurrentPoiModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }

    @Override // com.autonavi.amapauto.protocol.interaction.IProtocolAutoUserInterface
    public int setNaviMute(SetNaviMuteModel setNaviMuteModel, IProtocolCallback iProtocolCallback) {
        return this.mProtocolManager != null ? this.mProtocolManager.sendProtocolModelData(setNaviMuteModel, iProtocolCallback) : ProtocolResultCode.RESULT_UNINIT;
    }
}
