package com.ecarx.tip.dialog.base;

import android.app.Dialog;
import android.content.DialogInterface;
import android.graphics.drawable.Drawable;
import android.support.annotation.NonNull;
import android.support.annotation.StringRes;
import android.support.annotation.StyleRes;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.ecarx.tip.R;
import com.ecarx.tip.XCTip;
import com.ecarx.tip.base.BaseDialog;
import com.ecarx.tip.dialog.base.BaseContentDialog.Config;
import com.ecarx.tip.dialog.listener.OnClickListener;
import com.ecarx.tip.util.Utils;
/* loaded from: classes.dex */
public abstract class BaseContentDialog<T extends Config> extends BaseDialog<T> {
    private final byte BTN_LEFT = -1;
    private final byte BTN_RIGHT = -2;
    protected FrameLayout flDialogContent;
    protected LinearLayout llDialogBottom;
    protected LinearLayout llDialogTitle;
    protected TextView tvDialogLeftBtn;
    protected TextView tvDialogRightBtn;
    protected TextView tvDialogTitle;
    protected View viewDivideLine;

    protected abstract void onClickPositive();

    @Override // com.ecarx.tip.base.BaseDialog
    protected void setBaseView() {
        Dialog dialog = this.mDialog;
        View inflate = LayoutInflater.from(getContext()).inflate(R.layout.tip2_dialog_base_content, (ViewGroup) null);
        this.mContentView = inflate;
        dialog.setContentView(inflate);
        this.flDialogContent = (FrameLayout) findViewById(R.id.fl_dialog_content);
        this.flDialogContent.addView(LayoutInflater.from(getContext()).inflate(bindLayout(), (ViewGroup) null));
        this.llDialogTitle = (LinearLayout) findViewById(R.id.ll_dialog_title);
        this.tvDialogTitle = (TextView) findViewById(R.id.tv_dialog_title);
        this.llDialogBottom = (LinearLayout) findViewById(R.id.ll_dialog_bottom);
        this.tvDialogLeftBtn = (TextView) findViewById(R.id.tv_dialog_left_btn);
        this.viewDivideLine = findViewById(R.id.view_divide_line);
        this.tvDialogRightBtn = (TextView) findViewById(R.id.tv_dialog_right_btn);
        this.mWindow.setBackgroundDrawableResource(R.color.tip2_bg_dialog_mask);
        this.mWindow.setDimAmount(0.0f);
        ((Config) this.mConfig).setWidth(1.0f);
        ((Config) this.mConfig).setHeight(1.0f);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public void apply() {
        super.apply();
        LinearLayout.LayoutParams layoutParams = (LinearLayout.LayoutParams) this.flDialogContent.getLayoutParams();
        if (TextUtils.isEmpty(((Config) this.mConfig).title)) {
            int i = ((Config) this.mConfig).type;
            ((Config) this.mConfig).getClass();
            if (i == 1) {
                layoutParams.topMargin = Utils.getPixel(R.dimen.spacing_50);
                layoutParams.bottomMargin = Utils.getPixel(R.dimen.spacing_98);
            } else {
                int i2 = ((Config) this.mConfig).type;
                ((Config) this.mConfig).getClass();
                if (i2 == 2) {
                    layoutParams.bottomMargin = Utils.getPixel(R.dimen.spacing_58);
                } else {
                    int i3 = ((Config) this.mConfig).type;
                    ((Config) this.mConfig).getClass();
                    if (i3 == 3) {
                        layoutParams.bottomMargin = Utils.getPixel(R.dimen.spacing_58);
                    }
                }
            }
        } else {
            this.llDialogTitle.setVisibility(0);
            this.tvDialogTitle.setCompoundDrawablesWithIntrinsicBounds(Utils.getDrawableFromVector(R.drawable.tip2_ic_vector_title_prefix), (Drawable) null, (Drawable) null, (Drawable) null);
            this.tvDialogTitle.setText(((Config) this.mConfig).title);
            int i4 = ((Config) this.mConfig).type;
            ((Config) this.mConfig).getClass();
            if (i4 == 1) {
                layoutParams.topMargin = Utils.getPixel(R.dimen.spacing_26);
                layoutParams.bottomMargin = Utils.getPixel(R.dimen.spacing_78);
            } else {
                int i5 = ((Config) this.mConfig).type;
                ((Config) this.mConfig).getClass();
                if (i5 == 2) {
                    layoutParams.bottomMargin = Utils.getPixel(R.dimen.spacing_58);
                } else {
                    int i6 = ((Config) this.mConfig).type;
                    ((Config) this.mConfig).getClass();
                    if (i6 == 3) {
                        layoutParams.bottomMargin = Utils.getPixel(R.dimen.spacing_58);
                    }
                }
            }
        }
        this.flDialogContent.setLayoutParams(layoutParams);
        if (((Config) this.mConfig).leftListener != null || ((Config) this.mConfig).rightListener != null) {
            this.llDialogBottom.setVisibility(0);
            if (((Config) this.mConfig).leftListener != null && ((Config) this.mConfig).rightListener != null) {
                setButton(-1, ((Config) this.mConfig).leftText, ((Config) this.mConfig).leftListener);
                setButton(-2, ((Config) this.mConfig).rightText, ((Config) this.mConfig).rightListener);
            } else if (((Config) this.mConfig).leftListener != null) {
                setButton(-1, ((Config) this.mConfig).leftText, ((Config) this.mConfig).leftListener);
            } else {
                setButton(-2, ((Config) this.mConfig).rightText, ((Config) this.mConfig).rightListener);
            }
        }
    }

    private void setButton(int i, CharSequence charSequence, final OnClickListener onClickListener) {
        TextView textView;
        switch (i) {
            case -2:
                if (((Config) this.mConfig).isRightImportant) {
                    this.tvDialogRightBtn.setTextColor(ContextCompat.getColorStateList(getContext(), R.color.tip2_sel_dialog_btn_font_theme));
                }
                textView = this.tvDialogRightBtn;
                break;
            default:
                if (((Config) this.mConfig).isLeftImportant) {
                    this.tvDialogLeftBtn.setTextColor(ContextCompat.getColorStateList(getContext(), R.color.tip2_sel_dialog_btn_font_theme));
                }
                textView = this.tvDialogLeftBtn;
                break;
        }
        textView.setVisibility(0);
        textView.setText(charSequence);
        textView.setOnClickListener(new View.OnClickListener() { // from class: com.ecarx.tip.dialog.base.BaseContentDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (onClickListener.onClick(BaseContentDialog.this.mDialog, view)) {
                    ((Config) BaseContentDialog.this.mConfig).isClickPositive = true;
                }
            }
        });
        if (this.tvDialogLeftBtn.getVisibility() == 0 && this.tvDialogRightBtn.getVisibility() == 0) {
            this.viewDivideLine.setVisibility(0);
        }
    }

    @Override // android.support.v4.app.DialogFragment, android.content.DialogInterface.OnDismissListener
    public void onDismiss(DialogInterface dialogInterface) {
        super.onDismiss(dialogInterface);
        if (this.mConfig != 0 && ((Config) this.mConfig).isClickPositive) {
            onClickPositive();
            ((Config) this.mConfig).isClickPositive = false;
        }
    }

    /* loaded from: classes.dex */
    public class Config<T extends Config> extends BaseDialog.BaseConfig<T> {
        protected final int TYPE_MESSAGE;
        protected final int TYPE_SELECT_BUTTONS_NO_MSG;
        protected final int TYPE_SELECT_ITEMS;
        public boolean isClickPositive;
        boolean isLeftImportant;
        boolean isRightImportant;
        transient OnClickListener leftListener;
        CharSequence leftText;
        transient OnClickListener rightListener;
        CharSequence rightText;
        CharSequence title;
        protected int type;

        public Config() {
            this.TYPE_MESSAGE = 1;
            this.TYPE_SELECT_ITEMS = 2;
            this.TYPE_SELECT_BUTTONS_NO_MSG = 3;
        }

        public Config(@StyleRes int i) {
            super(i);
            this.TYPE_MESSAGE = 1;
            this.TYPE_SELECT_ITEMS = 2;
            this.TYPE_SELECT_BUTTONS_NO_MSG = 3;
        }

        public T setTitle(@StringRes int i) {
            return setTitle(XCTip.getApp().getText(i));
        }

        public T setTitle(@NonNull CharSequence charSequence) {
            this.title = charSequence;
            return this;
        }

        public T setLeftButton(@StringRes int i, @NonNull OnClickListener onClickListener) {
            return setLeftButton(XCTip.getApp().getText(i), false, onClickListener);
        }

        public T setLeftButton(@StringRes int i, boolean z, @NonNull OnClickListener onClickListener) {
            return setLeftButton(XCTip.getApp().getText(i), z, onClickListener);
        }

        public T setLeftButton(@NonNull CharSequence charSequence, @NonNull OnClickListener onClickListener) {
            return setLeftButton(charSequence, false, onClickListener);
        }

        public T setLeftButton(@NonNull CharSequence charSequence, boolean z, @NonNull OnClickListener onClickListener) {
            this.leftText = charSequence;
            this.isLeftImportant = z;
            this.leftListener = onClickListener;
            return this;
        }

        public T setRightButton(@StringRes int i, boolean z, @NonNull OnClickListener onClickListener) {
            return setRightButton(XCTip.getApp().getText(i), z, onClickListener);
        }

        public T setRightButton(@StringRes int i, @NonNull OnClickListener onClickListener) {
            return setRightButton(XCTip.getApp().getText(i), false, onClickListener);
        }

        public T setRightButton(CharSequence charSequence, OnClickListener onClickListener) {
            return setRightButton(charSequence, false, onClickListener);
        }

        public T setRightButton(CharSequence charSequence, boolean z, OnClickListener onClickListener) {
            this.rightText = charSequence;
            this.isRightImportant = z;
            this.rightListener = onClickListener;
            return this;
        }
    }
}
