package com.ecarx.tip.dialog.list.dialog;

import android.os.Bundle;
import android.support.annotation.StyleRes;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import com.ecarx.tip.R;
import com.ecarx.tip.XCTip;
import com.ecarx.tip.base.BaseDialog;
import com.ecarx.tip.dialog.base.BaseContentDialog;
import com.ecarx.tip.dialog.base.rv.listener.OnItemClickListener;
import com.ecarx.tip.dialog.list.adapter.SelectButtonsAdapter;
import com.ecarx.tip.dialog.list.bean.CheckBean;
import com.ecarx.tip.dialog.list.divider.SelectDivider;
import com.ecarx.tip.dialog.list.listener.OnSelectListener;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
/* loaded from: classes.dex */
public class SelectButtonsDialog extends BaseContentDialog<Config> {
    int curPos;
    List<CheckBean> mData;
    SelectButtonsAdapter mSelectButtonsAdapter;
    int prePos;
    RecyclerView rvList;

    public static SelectButtonsDialog newInstance(Config config) {
        Bundle bundle = new Bundle();
        bundle.putSerializable(BaseDialog.CONFIG_KEY, config);
        SelectButtonsDialog selectButtonsDialog = new SelectButtonsDialog();
        selectButtonsDialog.setArguments(bundle);
        return selectButtonsDialog;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public int bindLayout() {
        return R.layout.tip2_dialog_select_buttons;
    }

    @Override // com.ecarx.tip.base.BaseDialog
    protected void initView() {
        this.rvList = findViewById(R.id.rv_list_buttons);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public void apply(final Config config) {
        this.rvList.setLayoutManager(new LinearLayoutManager(XCTip.getApp()));
        this.mData = CheckBean.createData(config.mItems, config.mIsImportant);
        if (TextUtils.isEmpty(config.mMessage)) {
            this.rvList.addItemDecoration(new SelectDivider(getContext(), 1, R.drawable.tip2_divider_list));
            this.mSelectButtonsAdapter = new SelectButtonsAdapter(this.mData, R.layout.tip2_item_select_buttons_without_msg);
        } else {
            this.mSelectButtonsAdapter = new SelectButtonsAdapter(this.mData, R.layout.tip2_item_select_buttons_with_msg);
            TextView textView = (TextView) LayoutInflater.from(getContext()).inflate(R.layout.tip2_item_select_buttons_header, (ViewGroup) this.rvList, false);
            this.mSelectButtonsAdapter.setHeaderView(textView);
            textView.setText(config.mMessage);
            this.mSelectButtonsAdapter.setFooterView((TextView) LayoutInflater.from(getContext()).inflate(R.layout.tip2_item_select_buttons_footer, (ViewGroup) this.rvList, false));
        }
        this.mSelectButtonsAdapter.setOnItemClickListener(new OnItemClickListener() { // from class: com.ecarx.tip.dialog.list.dialog.SelectButtonsDialog.1
            @Override // com.ecarx.tip.dialog.base.rv.listener.OnItemClickListener
            public void onItemClick(View view, int i) {
                config.mListener.onSelect(SelectButtonsDialog.this.mDialog, i);
            }
        });
        this.rvList.setAdapter(this.mSelectButtonsAdapter);
    }

    @Override // com.ecarx.tip.dialog.base.BaseContentDialog
    protected void onClickPositive() {
    }

    /* loaded from: classes.dex */
    public class Config extends BaseContentDialog.Config<Config> {
        List<Boolean> mIsImportant;
        List<String> mItems;
        transient OnSelectListener mListener;
        String mMessage;

        public Config() {
        }

        public Config(@StyleRes int i) {
            super(i);
        }

        public Config setSelectButtons(String[] strArr, OnSelectListener onSelectListener) {
            Boolean[] boolArr = new Boolean[strArr.length];
            for (int i = 0; i < strArr.length; i++) {
                boolArr[i] = false;
            }
            return setSelectButtons((String) null, strArr, boolArr, onSelectListener);
        }

        public Config setSelectButtons(String[] strArr, Boolean[] boolArr, OnSelectListener onSelectListener) {
            return setSelectButtons((String) null, strArr, boolArr, onSelectListener);
        }

        public Config setSelectButtons(String str, String[] strArr, Boolean[] boolArr, OnSelectListener onSelectListener) {
            return setSelectButtons(str, Arrays.asList(strArr), Arrays.asList(boolArr), onSelectListener);
        }

        public Config setSelectButtons(List<String> list, OnSelectListener onSelectListener) {
            ArrayList arrayList = new ArrayList();
            for (int i = 0; i < list.size(); i++) {
                arrayList.add(false);
            }
            return setSelectButtons((String) null, list, arrayList, onSelectListener);
        }

        public Config setSelectButtons(List<String> list, List<Boolean> list2, OnSelectListener onSelectListener) {
            return setSelectButtons((String) null, list, list2, onSelectListener);
        }

        public Config setSelectButtons(String str, List<String> list, List<Boolean> list2, OnSelectListener onSelectListener) {
            if (TextUtils.isEmpty(str)) {
                this.type = 3;
            }
            this.mMessage = str;
            this.mItems = list;
            this.mIsImportant = list2;
            this.mListener = onSelectListener;
            return this;
        }
    }
}
