package com.ecarx.tip.dialog.list.dialog;

import android.os.Bundle;
import android.support.annotation.StyleRes;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.View;
import com.ecarx.tip.R;
import com.ecarx.tip.XCTip;
import com.ecarx.tip.base.BaseDialog;
import com.ecarx.tip.dialog.base.BaseContentDialog;
import com.ecarx.tip.dialog.base.rv.listener.OnItemClickListener;
import com.ecarx.tip.dialog.list.adapter.SelectItemsAdapter;
import com.ecarx.tip.dialog.list.bean.CheckBean;
import com.ecarx.tip.dialog.list.divider.SelectDivider;
import com.ecarx.tip.dialog.list.listener.OnSelectListener;
import java.util.Arrays;
import java.util.List;
/* loaded from: classes.dex */
public class SelectItemsDialog extends BaseContentDialog<Config> {
    int curPos;
    List<CheckBean> mData;
    SelectItemsAdapter mSelectItemsAdapter;
    int prePos;
    RecyclerView rvList;

    public static SelectItemsDialog newInstance(Config config) {
        Bundle bundle = new Bundle();
        bundle.putSerializable(BaseDialog.CONFIG_KEY, config);
        SelectItemsDialog selectItemsDialog = new SelectItemsDialog();
        selectItemsDialog.setArguments(bundle);
        return selectItemsDialog;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public int bindLayout() {
        return R.layout.tip2_dialog_select_items;
    }

    @Override // com.ecarx.tip.base.BaseDialog
    protected void initView() {
        this.rvList = findViewById(R.id.rv_list_items);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public void apply(final Config config) {
        this.rvList.setLayoutManager(new LinearLayoutManager(XCTip.getApp()));
        this.rvList.addItemDecoration(new SelectDivider(getContext(), 1, R.drawable.tip2_divider_list));
        int i = config.mSelectIndex;
        this.prePos = i;
        this.curPos = i;
        this.mData = CheckBean.createData(config.mItems, config.mSelectIndex);
        this.mSelectItemsAdapter = new SelectItemsAdapter(this.mData, R.layout.tip2_item_select_items);
        this.rvList.setAdapter(this.mSelectItemsAdapter);
        this.mSelectItemsAdapter.setOnItemClickListener(new OnItemClickListener() { // from class: com.ecarx.tip.dialog.list.dialog.SelectItemsDialog.1
            @Override // com.ecarx.tip.dialog.base.rv.listener.OnItemClickListener
            public void onItemClick(View view, int i2) {
                if (i2 != SelectItemsDialog.this.curPos) {
                    SelectItemsDialog.this.notifyItems(i2);
                }
                config.mListener.onSelect(SelectItemsDialog.this.mDialog, i2);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void notifyItems(int i) {
        this.prePos = this.curPos;
        this.curPos = i;
        this.mData.get(this.prePos).setChecked(false);
        this.mData.get(this.curPos).setChecked(true);
        this.mSelectItemsAdapter.notifyDataSetChanged();
    }

    @Override // com.ecarx.tip.dialog.base.BaseContentDialog
    protected void onClickPositive() {
    }

    /* loaded from: classes.dex */
    public class Config extends BaseContentDialog.Config<Config> {
        List<String> mItems;
        transient OnSelectListener mListener;
        int mSelectIndex;

        public Config() {
            this.mSelectIndex = -1;
            this.type = 2;
        }

        public Config(@StyleRes int i) {
            super(i);
            this.mSelectIndex = -1;
        }

        public Config setSelectItems(String[] strArr, int i, OnSelectListener onSelectListener) {
            return setSelectItems(Arrays.asList(strArr), i, onSelectListener);
        }

        public Config setSelectItems(List<String> list, int i, OnSelectListener onSelectListener) {
            this.mItems = list;
            this.mSelectIndex = i;
            this.mListener = onSelectListener;
            return this;
        }
    }
}
