package com.ecarx.tip.dialog.loading;

import android.animation.ValueAnimator;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.support.annotation.NonNull;
import android.support.annotation.StringRes;
import android.support.annotation.StyleRes;
import android.widget.ImageView;
import android.widget.TextView;
import com.airbnb.lottie.LottieAnimationView;
import com.ecarx.tip.R;
import com.ecarx.tip.XCTip;
import com.ecarx.tip.base.BaseDialog;
import com.ecarx.tip.util.Utils;
import java.lang.ref.WeakReference;
/* loaded from: classes.dex */
public class LoadingDialog extends BaseDialog<Config> {
    ImageView ivLoading;
    LottieAnimationView lavLoading;
    ValueAnimator.AnimatorUpdateListener mAnimatorUpdateListener;
    TextView tvLoadingMessage;
    final int LEAST_SHOW_TIME = 1000;
    final SafeHandler mHandler = new SafeHandler(this);

    public static LoadingDialog newInstance(Config config) {
        Bundle bundle = new Bundle();
        bundle.putSerializable(BaseDialog.CONFIG_KEY, config);
        LoadingDialog loadingDialog = new LoadingDialog();
        loadingDialog.setArguments(bundle);
        return loadingDialog;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public int bindLayout() {
        return R.layout.tip2_dialog_loading;
    }

    @Override // com.ecarx.tip.base.BaseDialog
    protected void initView() {
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public void apply(Config config) {
        this.lavLoading = (LottieAnimationView) findViewById(R.id.lav_loading);
        this.ivLoading = (ImageView) findViewById(R.id.iv_loading);
        this.tvLoadingMessage = (TextView) findViewById(R.id.tv_loading_message);
        this.mAnimatorUpdateListener = new ValueAnimator.AnimatorUpdateListener() { // from class: com.ecarx.tip.dialog.loading.LoadingDialog.1
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                LoadingDialog.this.ivLoading.setVisibility(8);
            }
        };
        this.lavLoading.a(this.mAnimatorUpdateListener);
        if (!Utils.isEmpty(config.loadMessage)) {
            this.tvLoadingMessage.setText(config.loadMessage);
        }
        this.mWindow.setBackgroundDrawableResource(17170445);
        this.mWindow.setDimAmount(0.0f);
        ((Config) this.mConfig).setWidth(1.0f);
        ((Config) this.mConfig).setHeight(1.0f);
    }

    @Override // com.ecarx.tip.base.BaseDialog, android.support.v4.app.DialogFragment
    public void dismiss() {
        long currentTimeMillis = System.currentTimeMillis() - this.startMillis;
        if (currentTimeMillis >= 1000) {
            super.dismiss();
        } else {
            this.mHandler.sendMessageDelayed(Message.obtain(), 1000 - currentTimeMillis);
        }
    }

    /* loaded from: classes.dex */
    public class Config extends BaseDialog.BaseConfig<Config> {
        CharSequence loadMessage;

        public Config() {
        }

        public Config(@StyleRes int i) {
            super(i);
        }

        public Config setLoadingMessage(@NonNull CharSequence charSequence) {
            this.loadMessage = charSequence;
            return this;
        }

        public Config setLoadingMessage(@StringRes int i) {
            this.loadMessage = XCTip.getApp().getText(i);
            return this;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public class SafeHandler extends Handler {
        WeakReference<LoadingDialog> mLoadingDialogWeakReference;

        public SafeHandler(LoadingDialog loadingDialog) {
            this.mLoadingDialogWeakReference = new WeakReference<>(loadingDialog);
        }

        @Override // android.os.Handler
        public void handleMessage(Message message) {
            LoadingDialog loadingDialog = this.mLoadingDialogWeakReference.get();
            if (loadingDialog != null) {
                loadingDialog.dismiss();
            }
        }
    }

    @Override // android.support.v4.app.Fragment
    public void onDestroy() {
        super.onDestroy();
        this.lavLoading.d();
        if (this.mAnimatorUpdateListener != null) {
            this.lavLoading.b(this.mAnimatorUpdateListener);
        }
    }
}
