package com.ecarx.tip.dialog.message;

import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.StringRes;
import android.support.annotation.StyleRes;
import android.support.v4.view.GravityCompat;
import android.view.View;
import android.widget.CheckedTextView;
import android.widget.TextView;
import com.ecarx.tip.R;
import com.ecarx.tip.XCTip;
import com.ecarx.tip.base.BaseDialog;
import com.ecarx.tip.dialog.base.BaseContentDialog;
import com.ecarx.tip.util.Utils;
/* loaded from: classes.dex */
public class MessageDialog extends BaseContentDialog<Config> {
    private CheckedTextView ctvCheck;
    private TextView tvConfirmMessage;

    /* loaded from: classes.dex */
    public interface CheckedCallback {
        void checkedCallback();
    }

    public static MessageDialog newInstance(Config config) {
        Bundle bundle = new Bundle();
        bundle.putSerializable(BaseDialog.CONFIG_KEY, config);
        MessageDialog messageDialog = new MessageDialog();
        messageDialog.setArguments(bundle);
        return messageDialog;
    }

    @Override // com.ecarx.tip.base.BaseDialog
    protected int bindLayout() {
        return R.layout.tip2_dialog_message;
    }

    @Override // com.ecarx.tip.base.BaseDialog
    protected void initView() {
        this.tvConfirmMessage = (TextView) findViewById(R.id.tv_confirm_message);
        this.ctvCheck = (CheckedTextView) findViewById(R.id.ctv_check);
        this.ctvCheck.setCompoundDrawablesWithIntrinsicBounds(Utils.getDrawableFromVector(R.drawable.tip2_sel_dialog_msg_check, false), (Drawable) null, (Drawable) null, (Drawable) null);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public void apply(final Config config) {
        this.tvConfirmMessage.setText(config.message);
        this.tvConfirmMessage.post(new Runnable() { // from class: com.ecarx.tip.dialog.message.MessageDialog.1
            @Override // java.lang.Runnable
            public void run() {
                if (MessageDialog.this.tvConfirmMessage.getLineCount() != 1) {
                    MessageDialog.this.tvConfirmMessage.setGravity(GravityCompat.START);
                } else if (config.checkStatusCallback == null) {
                    MessageDialog.this.tvConfirmMessage.setGravity(1);
                } else {
                    MessageDialog.this.tvConfirmMessage.setGravity(GravityCompat.START);
                }
            }
        });
        this.ctvCheck.setOnClickListener(new View.OnClickListener() { // from class: com.ecarx.tip.dialog.message.MessageDialog.2
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                MessageDialog.this.ctvCheck.setCompoundDrawablesWithIntrinsicBounds(Utils.getDrawableFromVector(R.drawable.tip2_sel_dialog_msg_check), (Drawable) null, (Drawable) null, (Drawable) null);
                MessageDialog.this.ctvCheck.toggle();
            }
        });
        if (config.checkStatusCallback != null) {
            this.ctvCheck.setVisibility(0);
            this.ctvCheck.setChecked(config.isChecked);
            this.ctvCheck.setText(config.checkMsg);
        }
    }

    @Override // com.ecarx.tip.dialog.base.BaseContentDialog
    protected void onClickPositive() {
        if (((Config) this.mConfig).checkStatusCallback != null && this.ctvCheck.isChecked()) {
            ((Config) this.mConfig).checkStatusCallback.checkedCallback();
        }
    }

    /* loaded from: classes.dex */
    public class Config extends BaseContentDialog.Config<Config> {
        CharSequence checkMsg;
        transient CheckedCallback checkStatusCallback;
        boolean isChecked;
        CharSequence message;

        public Config() {
            this.type = 1;
        }

        public Config(@StyleRes int i) {
            super(i);
        }

        public Config setMessage(@StringRes int i) {
            return setMessage(XCTip.getApp().getText(i));
        }

        public Config setMessage(@NonNull CharSequence charSequence) {
            this.message = charSequence;
            return this;
        }

        public Config setCheckBox(boolean z, @StringRes int i, CheckedCallback checkedCallback) {
            return setCheckBox(z, XCTip.getApp().getText(i), checkedCallback);
        }

        public Config setCheckBox(boolean z, @NonNull CharSequence charSequence, CheckedCallback checkedCallback) {
            this.isChecked = z;
            this.checkMsg = charSequence;
            this.checkStatusCallback = checkedCallback;
            return this;
        }
    }
}
