package com.ecarx.tip.dialog.picker.dialog;

import android.annotation.SuppressLint;
import android.os.Bundle;
import android.support.annotation.IntRange;
import android.support.annotation.StyleRes;
import android.view.View;
import android.widget.CheckedTextView;
import android.widget.RelativeLayout;
import com.ecarx.tip.R;
import com.ecarx.tip.base.BaseDialog;
import com.ecarx.tip.dialog.base.BaseContentDialog;
import com.ecarx.tip.dialog.picker.listener.OnPickListener;
import com.ecarx.tip.dialog.picker.view.Picker;
import com.ecarx.tip.util.Utils;
import java.util.Calendar;
import java.util.Locale;
/* loaded from: classes.dex */
public class PickerDialog extends BaseContentDialog<Config> {
    private static final int NOW_YEAR = 2018;
    private static final int START_YEAR = 2016;
    CheckedTextView ctvPickerEnd;
    CheckedTextView ctvPickerStart;
    Picker pickerMonth;
    Picker pickerYear;
    RelativeLayout rlPickerTop;

    public static PickerDialog newInstance(Config config) {
        Bundle bundle = new Bundle();
        bundle.putSerializable(BaseDialog.CONFIG_KEY, config);
        PickerDialog pickerDialog = new PickerDialog();
        pickerDialog.setArguments(bundle);
        return pickerDialog;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public int bindLayout() {
        return R.layout.tip2_dialog_picker;
    }

    @Override // com.ecarx.tip.base.BaseDialog
    protected void initView() {
        this.rlPickerTop = (RelativeLayout) findViewById(R.id.rl_picker_top);
        this.ctvPickerStart = (CheckedTextView) findViewById(R.id.ctv_picker_start);
        this.ctvPickerEnd = (CheckedTextView) findViewById(R.id.ctv_picker_end);
        this.pickerYear = (Picker) findViewById(R.id.picker_year);
        this.pickerMonth = (Picker) findViewById(R.id.picker_month);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.ecarx.tip.base.BaseDialog
    public void apply(final Config config) {
        this.pickerYear.setMinValue(START_YEAR);
        this.pickerYear.setMaxValue(config.mMaxYear);
        this.pickerYear.setValue(config.mYear);
        if (config.mMaxYearMaxMonth != 0) {
            this.tvDialogRightBtn.setEnabled(false);
            this.rlPickerTop.setVisibility(0);
            this.pickerMonth.setVisibility(0);
            this.pickerMonth.setMinValue(1);
            this.pickerMonth.setValue(config.mMonth);
            if (this.pickerYear.getValue() == config.mMaxYear) {
                this.pickerMonth.setMaxValue(config.mMaxYearMaxMonth);
            } else {
                this.pickerMonth.setMaxValue(12);
            }
            this.ctvPickerStart.setOnClickListener(new View.OnClickListener() { // from class: com.ecarx.tip.dialog.picker.dialog.PickerDialog.1
                @Override // android.view.View.OnClickListener
                public void onClick(View view) {
                    PickerDialog.this.ctvPickerEnd.setChecked(false);
                    if (!PickerDialog.this.ctvPickerStart.isChecked()) {
                        PickerDialog.this.ctvPickerStart.setChecked(true);
                    }
                    PickerDialog.this.updatePicker((String) PickerDialog.this.ctvPickerStart.getText());
                }
            });
            this.ctvPickerEnd.setOnClickListener(new View.OnClickListener() { // from class: com.ecarx.tip.dialog.picker.dialog.PickerDialog.2
                @Override // android.view.View.OnClickListener
                public void onClick(View view) {
                    PickerDialog.this.ctvPickerStart.setChecked(false);
                    if (!PickerDialog.this.ctvPickerEnd.isChecked()) {
                        PickerDialog.this.ctvPickerEnd.setChecked(true);
                    }
                    String str = (String) PickerDialog.this.ctvPickerEnd.getText();
                    if (!Utils.getString(R.string.tip2_end_time).equals(str)) {
                        PickerDialog.this.updatePicker(str);
                        return;
                    }
                    PickerDialog.this.ctvPickerEnd.setText(PickerDialog.this.ctvPickerStart.getText());
                    PickerDialog.this.ctvPickerEnd.setTextSize(0, Utils.getDimension(R.dimen.font_30));
                    PickerDialog.this.ctvPickerEnd.setAlpha(1.0f);
                    PickerDialog.this.tvDialogRightBtn.setEnabled(true);
                }
            });
            this.pickerYear.setOnValueChangedListener(new Picker.OnValueChangeListener() { // from class: com.ecarx.tip.dialog.picker.dialog.PickerDialog.3
                @Override // com.ecarx.tip.dialog.picker.view.Picker.OnValueChangeListener
                public void onValueChange(Picker picker, int i, int i2) {
                    if (i2 == config.mMaxYear) {
                        if (PickerDialog.this.pickerMonth.getValue() > config.mMaxYearMaxMonth) {
                            PickerDialog.this.pickerMonth.setValue(1);
                        }
                        PickerDialog.this.pickerMonth.setMaxValue(config.mMaxYearMaxMonth);
                    } else {
                        PickerDialog.this.pickerMonth.setMaxValue(12);
                    }
                    PickerDialog.this.updateTime();
                }
            });
            this.pickerMonth.setOnValueChangedListener(new Picker.OnValueChangeListener() { // from class: com.ecarx.tip.dialog.picker.dialog.PickerDialog.4
                @Override // com.ecarx.tip.dialog.picker.view.Picker.OnValueChangeListener
                public void onValueChange(Picker picker, int i, int i2) {
                    PickerDialog.this.updateTime();
                }
            });
            updateTime();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void updateTime() {
        String format = String.format(Locale.getDefault(), "%d-%02d", Integer.valueOf(this.pickerYear.getValue()), Integer.valueOf(this.pickerMonth.getValue()));
        if (this.ctvPickerStart.isChecked()) {
            this.ctvPickerStart.setText(format);
        } else {
            this.ctvPickerEnd.setText(format);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void updatePicker(String str) {
        String[] split = str.split("-");
        int parseInt = Integer.parseInt(split[0]);
        int parseInt2 = Integer.parseInt(split[1]);
        if (parseInt == ((Config) this.mConfig).mMaxYear) {
            this.pickerMonth.setMaxValue(((Config) this.mConfig).mMaxYearMaxMonth);
        } else {
            this.pickerMonth.setMaxValue(12);
        }
        this.pickerYear.setValue(parseInt);
        this.pickerMonth.setValue(parseInt2);
    }

    @Override // com.ecarx.tip.dialog.base.BaseContentDialog
    protected void onClickPositive() {
        boolean z;
        if (((Config) this.mConfig).mOnPickListener != null) {
            if (((Config) this.mConfig).mMaxYearMaxMonth == 0) {
                ((Config) this.mConfig).mOnPickListener.onPick(String.valueOf(this.pickerYear.getValue()));
                return;
            }
            String[] split = ((String) this.ctvPickerStart.getText()).split("-");
            String[] split2 = ((String) this.ctvPickerEnd.getText()).split("-");
            int parseInt = Integer.parseInt(split[0]);
            int parseInt2 = Integer.parseInt(split[1]);
            int parseInt3 = Integer.parseInt(split2[0]);
            int parseInt4 = Integer.parseInt(split2[1]);
            if (parseInt < parseInt3) {
                z = true;
            } else {
                z = parseInt == parseInt3 && parseInt2 <= parseInt4;
            }
            if (z) {
                ((Config) this.mConfig).mOnPickListener.onPick(parseInt + "/" + parseInt2 + "-" + parseInt3 + "/" + parseInt4);
            } else {
                ((Config) this.mConfig).mOnPickListener.onPick(parseInt3 + "/" + parseInt4 + "-" + parseInt + "/" + parseInt2);
            }
        }
    }

    /* loaded from: classes.dex */
    public class Config extends BaseContentDialog.Config<Config> {
        int mMaxYear;
        int mMaxYearMaxMonth;
        int mMonth;
        transient OnPickListener mOnPickListener;
        int mYear;

        public Config() {
        }

        public Config(@StyleRes int i) {
            super(i);
        }

        @SuppressLint({"Range"})
        public Config setPicker(@IntRange(from = 2016) int i, OnPickListener onPickListener) {
            return setPicker(i, -7, onPickListener);
        }

        public Config setPicker(@IntRange(from = 2016) int i, @IntRange(from = 1, to = 12) int i2, OnPickListener onPickListener) {
            this.mOnPickListener = onPickListener;
            Calendar calendar = Calendar.getInstance();
            int i3 = calendar.get(1);
            if (i3 < PickerDialog.NOW_YEAR) {
                throw new RuntimeException("system time is wrong");
            }
            this.mMaxYear = i3;
            if (i < PickerDialog.START_YEAR || i > i3) {
                Utils.logW("the year should between 2016 to the year of now");
                if (i < PickerDialog.START_YEAR) {
                    this.mYear = PickerDialog.START_YEAR;
                } else if (i > i3) {
                    this.mYear = i3;
                }
            } else {
                this.mYear = i;
            }
            if (-7 != i2) {
                int i4 = calendar.get(2) + 1;
                if (i == i3 && i2 > i4) {
                    this.mMonth = 1;
                } else {
                    this.mMonth = i2;
                }
                this.mMaxYearMaxMonth = i4;
            }
            return this;
        }
    }
}
