package ecarx.locationservice;

import android.app.Application;
import android.os.Binder;
import android.os.RemoteCallbackList;
import android.os.RemoteException;
import android.text.TextUtils;
import ecarx.locationservice.ILocationService;
import ecarx.naviservice.common.aa;
import java.io.Serializable;
/* loaded from: classes.dex */
public class LocService extends ILocationService.Stub {
    public static final boolean DEFAULT_GPS_SIGNAL = false;
    private static final float GPS_SIGNAL_WEAKNESS = 20.0f;
    public static final String KEY_GPS_SIGNAL_WEAKNESS = "GPS_SIGNAL_WEAKNESS";
    public static final String LOCATION_INFO_CACHE_FILE = "location_info_file";
    public static final String LOCATION_INFO_CACHE_KEY = "location_info_key";
    private static final int MIN_SATELLITES_TO_LOCATE = 4;
    private static final String TAG = "LocService";
    public static LocationInfo locationInfo;
    private final Application mApp;
    private AMapLocationWrapper mLastLocation;
    public static double LAT = 0.0d;
    public static double LON = 0.0d;
    private final Object notifyLock = new Object();
    private boolean mGpsSignalWeakness = false;
    private ecarx.naviservice.common.a cacheUtils = ecarx.naviservice.common.a.a(LOCATION_INFO_CACHE_FILE);
    private final RemoteCallbackList<ILocationObserver> callbacks = new d(this);

    private void notifyDistrictChanged(ILocation iLocation) {
        aa.c(TAG, String.format("notifyDistrictChanged: %s", iLocation));
        synchronized (this.notifyLock) {
            int beginBroadcast = this.callbacks.beginBroadcast();
            int i = 0;
            while (beginBroadcast > 0) {
                int i2 = beginBroadcast - 1;
                try {
                    this.callbacks.getBroadcastItem(i2).onDistrictChanged(iLocation);
                    i++;
                    beginBroadcast = i2;
                } catch (RemoteException e) {
                    e.printStackTrace();
                    beginBroadcast = i2;
                }
            }
            this.callbacks.finishBroadcast();
            aa.c(TAG, String.format("notifyDistrictChanged notified count: %s", Integer.valueOf(i)));
        }
    }

    private void notifyCityChanged(ILocation iLocation) {
        aa.c(TAG, String.format("notifyCityChanged: %s", iLocation));
        synchronized (this.notifyLock) {
            int beginBroadcast = this.callbacks.beginBroadcast();
            int i = 0;
            while (beginBroadcast > 0) {
                int i2 = beginBroadcast - 1;
                try {
                    this.callbacks.getBroadcastItem(i2).onCityChanged(iLocation);
                    i++;
                    beginBroadcast = i2;
                } catch (RemoteException e) {
                    e.printStackTrace();
                    beginBroadcast = i2;
                }
            }
            this.callbacks.finishBroadcast();
            aa.c(TAG, String.format("notifyCityChanged notified count: %s", Integer.valueOf(i)));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void notifyLocationChanged(ILocation iLocation) {
        aa.c(TAG, String.format("notifyLocationChanged: %s", iLocation));
        synchronized (this.notifyLock) {
            int beginBroadcast = this.callbacks.beginBroadcast();
            int i = 0;
            while (beginBroadcast > 0) {
                int i2 = beginBroadcast - 1;
                try {
                    this.callbacks.getBroadcastItem(i2).onLocation(iLocation);
                    i++;
                    beginBroadcast = i2;
                } catch (RemoteException e) {
                    e.printStackTrace();
                    beginBroadcast = i2;
                }
            }
            this.callbacks.finishBroadcast();
            aa.c(TAG, String.format("notifyLocationChanged notified count: %s", Integer.valueOf(i)));
        }
    }

    public LocService(Application application) {
        this.mApp = application;
        initLocation();
    }

    public void onDestroy() {
        h.a(this.mApp.getApplicationContext()).a();
    }

    @Override // ecarx.locationservice.ILocationService
    public ILocation getLastKnownLocation() {
        locationInfo = (LocationInfo) this.cacheUtils.c(LOCATION_INFO_CACHE_KEY);
        aa.c(TAG, String.format("getLastKnownLocation  mLastLocation:%s \n initLocation:%s", this.mLastLocation, locationInfo));
        if (locationInfo != null) {
            this.mLastLocation = new AMapLocationWrapper(locationInfo);
            LAT = locationInfo.getLatitude();
            LON = locationInfo.getLongitude();
        }
        return this.mLastLocation;
    }

    @Override // ecarx.locationservice.ILocationService
    public boolean attachLocationObserver(ILocationObserver iLocationObserver) {
        boolean register;
        aa.c(TAG, String.format("attachLocationObserver from: %s", Integer.valueOf(Binder.getCallingPid())));
        synchronized (this.notifyLock) {
            int registeredCallbackCount = this.callbacks.getRegisteredCallbackCount();
            register = this.callbacks.register(iLocationObserver);
            int registeredCallbackCount2 = this.callbacks.getRegisteredCallbackCount();
            if (register && registeredCallbackCount == 0 && registeredCallbackCount2 == 1) {
                aa.c(TAG, "have callbacks, register amap location listener");
                ecarx.a.c.a().a(new e(this));
            }
        }
        return register;
    }

    @Override // ecarx.locationservice.ILocationService
    public boolean detachLocationObserver(ILocationObserver iLocationObserver) {
        boolean unregister = this.callbacks.unregister(iLocationObserver);
        if (unregister) {
        }
        return unregister;
    }

    private synchronized void initLocation() {
        locationInfo = (LocationInfo) this.cacheUtils.c(LOCATION_INFO_CACHE_KEY);
        aa.c(TAG, String.format("initLocation:%s", locationInfo));
        if (locationInfo != null) {
            this.mLastLocation = new AMapLocationWrapper(locationInfo);
            LAT = locationInfo.getLatitude();
            LON = locationInfo.getLongitude();
            notifyLocationChanged(this.mLastLocation);
            notifyCityChanged(this.mLastLocation);
            notifyDistrictChanged(this.mLastLocation);
        }
        h.a(this.mApp.getApplicationContext()).a(new f(this));
    }

    public void locationDetailResp(String str, String str2, String str3, String str4) {
        if (locationInfo != null) {
            boolean z = false;
            if (!TextUtils.isEmpty(str2) && !str2.equals(locationInfo.getCity())) {
                z = true;
            }
            locationInfo.setProvince(str);
            locationInfo.setCity(str2);
            locationInfo.setAdCode(str3);
            locationInfo.setCountry(str4);
            this.mLastLocation = new AMapLocationWrapper(locationInfo);
            this.cacheUtils.a(LOCATION_INFO_CACHE_KEY, (Serializable) locationInfo);
            if (z) {
                notifyCityChanged(this.mLastLocation);
                notifyDistrictChanged(this.mLastLocation);
            }
        }
    }
}
